=======
hierArc
=======


.. image:: https://img.shields.io/pypi/v/hierarc.svg
        :target: https://pypi.python.org/pypi/hierarc

.. image:: https://img.shields.io/travis/sibirrer/hierarc.svg
        :target: https://travis-ci.com/sibirrer/hierarc

.. image:: https://coveralls.io/repos/github/sibirrer/hierArc/badge.svg?branch=master
    :target: https://coveralls.io/github/sibirrer/hierArc?branch=master

.. image:: https://readthedocs.org/projects/hierarc/badge/?version=latest
        :target: https://hierarc.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: http://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat
        :target: http://www.astropy.org
        :alt: Powered by Astropy Badge



Hierarchical analysis of strong lensing systems to infer lens properties and cosmological parameters simultaneously


* Free software: BSD license
* Documentation: https://hierarc.readthedocs.io.


Features
--------

* Hierarchical analysis of strong gravitational lenses

Credits
-------

Simon Birrer & the TDCOSMO team
